==> kendo-window-react-wrapper-2018.1.117.tgz: package/docs/index.md <==
---
title: Overview
description: "Get an overview of the features the Kendo UI Window delivers and use the wrapper in React projects."
slug: overview_window
position: 0
---

# Window Overview

The Window displays content in a modal or non-modal HTML window and, by default, can be moved, resized, and closed.

The Window wrapper is a client-side wrapper for the [Kendo UI Window](https://docs.telerik.com/kendo-ui/api/javascript/ui/window) widget.

## Basic Usage

The following example demonstrates the Window in action.

```jsx-preview

    class LayoutsContainer extends React.Component {

      open() {
              $("[data-role='window']").each(function (index) {
                  $(this).data('kendoWindow').open()});
          }

      render() {
        return (
          <div>
                <Window title={"About Alvar Aalto"} width={"640px"}>
                    <p>Alvar Aalto is one of the greatest names in modern architecture and design. Glassblowers at the iittala factory still meticulously handcraft the legendary vases that are variations on one theme, fluid organic shapes that let the end user decide the use. Interpretations of the shape in new colors and materials add to the growing Alvar Aalto Collection that remains true to his original design.</p>

                    <p>Born Hugo Alvar Henrik Aalto (February 3, 1898 - May 11, 1976) in Kuortane, Finland, was noted for his humanistic approach to modernism. He studied architecture at the Helsinki University of Technology from 1916 to 1921. In 1924 he married architect Aino Marsio.</p>

                    <p>Alvar Aalto was one of the first and most influential architects of the Scandinavian modern movement, and a member of the Congres Internationaux d'Architecture Moderne. Major architectural works include the Finlandia Hall in Helsinki, Finland, and the campus of Helsinki University of Technology.</p>
                </Window>
                <span id="undo" className="k-button" onClick={this.open}>Click here to open the Window</span>
            </div>
        );
      }
    }

    ReactDOM.render(
      <LayoutsContainer  />,
      document.querySelector('my-app')
    );
```

## Installation

All components that you reference during the installation will be present in the final bundle of your application. To avoid ending up with components you do not actually need, import only the used component from the package.

1. Download and install the package:

    ```sh
        npm install --save @progress/kendo-window-react-wrapper
    ```

2. Once installed, import the Window component from the package.

    ```sh
        import { Window } from '@progress/kendo-window-react-wrapper';
    ```

3. You are required to install one of the Kendo UI themes to style your components.

## Dependencies

The TreeView package requires you to install the following [peer dependencies](https://nodejs.org/en/blog/npm/peer-dependencies/) in your application:

* @progress/kendo-ui

## Features and Functionalities

The Window enables you to [customize its actions]({% slug customizing_actions_window %}).

## Events

The following example demonstrates basic Window events. You can subscribe to [all Window events](http://docs.telerik.com/kendo-ui/api/javascript/ui/window#events) by the handler name.

```jsx-preview

    class LayoutsContainer extends React.Component {

      open() {
              $("[data-role='window']").each(function (index) {
                  $(this).data('kendoWindow').open()});
          }

          onOpen(){
              console.log('Open event was triggered!');
          }

           onClose(){
              console.log('Close event was triggered!');
          }

           onDragStart(){
              console.log('DragStart event was triggered!');
          }

           onDragEnd(){
              console.log('DragEnd event was triggered!');
          }

      render() {
        return (
          <div>
                <Window open={this.onOpen} close={this.onClose} dragstart={this.onDragStart} dragend={this.onDragEnd} title={"About Alvar Aalto"} width={"640px"}>
                    <p>Alvar Aalto is one of the greatest names in modern architecture and design. Glassblowers at the iittala factory still meticulously handcraft the legendary vases that are variations on one theme, fluid organic shapes that let the end user decide the use. Interpretations of the shape in new colors and materials add to the growing Alvar Aalto Collection that remains true to his original design.</p>

                    <p>Born Hugo Alvar Henrik Aalto (February 3, 1898 - May 11, 1976) in Kuortane, Finland, was noted for his humanistic approach to modernism. He studied architecture at the Helsinki University of Technology from 1916 to 1921. In 1924 he married architect Aino Marsio.</p>

                    <p>Alvar Aalto was one of the first and most influential architects of the Scandinavian modern movement, and a member of the Congres Internationaux d'Architecture Moderne. Major architectural works include the Finlandia Hall in Helsinki, Finland, and the campus of Helsinki University of Technology.</p>
                </Window>
                <span id="undo" className="k-button" onClick={this.open}>Click here to open the Window</span>
            </div>
        );
      }
    }

    ReactDOM.render(
      <LayoutsContainer  />,
      document.querySelector('my-app')
    );
```

## Suggested Links

* [Kendo UI Window for jQuery](https://docs.telerik.com/kendo-ui/controls/layout/window/overview)

==> kendo-window-react-wrapper-2018.1.131.tgz: package/docs/index.md <==
---
title: Overview
page_title: Window Overview - Components - Kendo UI Wrappers for React
description: "Get an overview of the features the Kendo UI Window wrapper for React delivers and use the component in React projects."
slug: overview_window
position: 0
---

# Window Overview

The Window displays content in a modal or non-modal HTML window and, by default, can be moved, resized, and closed.

The Window wrapper for React is a client-side wrapper for the [Kendo UI Window](https://docs.telerik.com/kendo-ui/api/javascript/ui/window) widget.

## Basic Usage

The following example demonstrates the Window in action.

```jsx-preview

    class LayoutsContainer extends React.Component {

      open() {
              $("[data-role='window']").each(function (index) {
                  $(this).data('kendoWindow').open()});
          }

      render() {
        return (
          <div>
                <Window title={"About Alvar Aalto"} width={"640px"}>
                    <p>Alvar Aalto is one of the greatest names in modern architecture and design. Glassblowers at the iittala factory still meticulously handcraft the legendary vases that are variations on one theme, fluid organic shapes that let the end user decide the use. Interpretations of the shape in new colors and materials add to the growing Alvar Aalto Collection that remains true to his original design.</p>

                    <p>Born Hugo Alvar Henrik Aalto (February 3, 1898 - May 11, 1976) in Kuortane, Finland, was noted for his humanistic approach to modernism. He studied architecture at the Helsinki University of Technology from 1916 to 1921. In 1924 he married architect Aino Marsio.</p>

                    <p>Alvar Aalto was one of the first and most influential architects of the Scandinavian modern movement, and a member of the Congres Internationaux d'Architecture Moderne. Major architectural works include the Finlandia Hall in Helsinki, Finland, and the campus of Helsinki University of Technology.</p>
                </Window>
                <span id="undo" className="k-button" onClick={this.open}>Click here to open the Window</span>
            </div>
        );
      }
    }

    ReactDOM.render(
      <LayoutsContainer  />,
      document.querySelector('my-app')
    );
```

## Installation

1. Download and install the package.

    ```sh
        npm install --save @progress/kendo-window-react-wrapper
    ```

2. Once installed, import the Window component from the package.

    ```sh
        import { Window } from '@progress/kendo-window-react-wrapper';
    ```

3. You are required to install one of the Kendo UI themes to style your components.

## Dependencies

The Window package requires you to install the following [peer dependencies](https://nodejs.org/en/blog/npm/peer-dependencies/) in your application:

* @progress/kendo-ui

## Features and Functionalities

The Window delivers options for [customizing its actions]({% slug customizing_actions_window %}).

## Events

The following example demonstrates basic Window events. You can subscribe to [all Window events](http://docs.telerik.com/kendo-ui/api/javascript/ui/window#events) by the handler name.

```jsx

    class LayoutsContainer extends React.Component {

      open() {
              $("[data-role='window']").each(function (index) {
                  $(this).data('kendoWindow').open()});
          }

          onOpen(){
              console.log('Open event was triggered!');
          }

           onClose(){
              console.log('Close event was triggered!');
          }

           onDragStart(){
              console.log('DragStart event was triggered!');
          }

           onDragEnd(){
              console.log('DragEnd event was triggered!');
          }

      render() {
        return (
          <div>
                <Window open={this.onOpen} close={this.onClose} dragstart={this.onDragStart} dragend={this.onDragEnd} title={"About Alvar Aalto"} width={"640px"}>
                    <p>Alvar Aalto is one of the greatest names in modern architecture and design. Glassblowers at the iittala factory still meticulously handcraft the legendary vases that are variations on one theme, fluid organic shapes that let the end user decide the use. Interpretations of the shape in new colors and materials add to the growing Alvar Aalto Collection that remains true to his original design.</p>

                    <p>Born Hugo Alvar Henrik Aalto (February 3, 1898 - May 11, 1976) in Kuortane, Finland, was noted for his humanistic approach to modernism. He studied architecture at the Helsinki University of Technology from 1916 to 1921. In 1924 he married architect Aino Marsio.</p>

                    <p>Alvar Aalto was one of the first and most influential architects of the Scandinavian modern movement, and a member of the Congres Internationaux d'Architecture Moderne. Major architectural works include the Finlandia Hall in Helsinki, Finland, and the campus of Helsinki University of Technology.</p>
                </Window>
                <span id="undo" className="k-button" onClick={this.open}>Click here to open the Window</span>
            </div>
        );
      }
    }

    ReactDOM.render(
      <LayoutsContainer  />,
      document.querySelector('my-app')
    );
```

## Suggested Links

* [Kendo UI Window for jQuery](https://docs.telerik.com/kendo-ui/controls/layout/window/overview)
* [API Reference of the Window Widget](http://docs.telerik.com/kendo-ui/api/javascript/ui/window)
